@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration
 
-our $VERSION = '0.0301';
+our $VERSION = '0.0302';
 
 use Moo;
 use strictures 2;
@@ -122,7 +122,7 @@ Music::Duration::Partition - Partition a musical duration
 
 =head1 VERSION
 
-version 0.0301
+version 0.0302
 
 =head1 SYNOPSIS
 
@@ -133,7 +133,7 @@ version 0.0301
     pool => [qw/ qn en sn /],
   );
 
-  $mdp->pool_code( sub { ... } );
+  $mdp->pool_code( sub { ... } ); # Optional
 
   my $motif = $mdp->motif;
 
@@ -229,9 +229,9 @@ Return the duration value of the given name.
 
 Generate a rhythmic phrase of the given B<size>.
 
-Currently, this is constructed by selecting a B<pool> duration at
-random, that fits into the size remaining after each application, in a
-loop until the B<size> is met.
+The default B<pool_code> used constructs this by selecting a B<pool>
+duration at random, that fits into the size remaining after each
+application, in a loop until the B<size> is met.
 
 =head1 SEE ALSO
 
